Supported sensors — PolSARtools 0.10 documentation

Skip to main content
`Ctrl`+`K`

# Supported sensors

PolSARtools currently supports the import of sensor data from the following sources into polarimetric matrices.

- 🔸UAVSAR
  - GRD (`import_uavsar_grd`)
  - MLC (`import_uavsar_mlc`)
- 🔸ISRO ASAR
  - RSLC (`import_isro_asar`)
- 🔸ESAR
  - GTC SLC (`import_esar_gtc`)
- 🔸NISAR
  - RSLC (`import_nisar_rslc`)
  - GSLC (`import_nisar_gslc`)
- 🔸RISAT-1A
  - Level 1.1 (`import_risat_l11`)
- 🔸RADARSAT-2
  - Full-pol (`import_rs2_fp`)
- 🔸ALOS-2 PALSAR-2
  - FBD L1.1 (`import_alos2_fbd_l11`)
  - HBQ L1.1 (`import_alos2_hbq_l11`)
  - WBD L1.1 (`import_alos2_wbd_l11`)
- 🔸Chandrayaan-II (DFSAR)
  - Full-pol (`import_chyaan2_fp`)
  - Compact-pol (`import_chyaan2_cp`)